smrf.spatial package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   smrf.spatial.dk

Submodules
----------

smrf.spatial.grid module
------------------------

.. automodule:: smrf.spatial.grid
   :members:
   :undoc-members:
   :show-inheritance:

smrf.spatial.idw module
-----------------------

.. automodule:: smrf.spatial.idw
   :members:
   :undoc-members:
   :show-inheritance:

smrf.spatial.kriging module
---------------------------

.. automodule:: smrf.spatial.kriging
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: smrf.spatial
   :members:
   :undoc-members:
   :show-inheritance:
